@@ -50,11 +50,10 @@ protected:
 DetailWindow::DetailWindow(Target * _target, const QString & groupName, int istemplate, bool edit, eWallet *paTarget, QWidget *parent) :
 		QMainWindow(parent)
 {
+	//settings.setValue("hints/phoneNumber/supportCharacters", true);
+
 	setWindowTitle("Wallet");
 
-//	this->setAttribute(Qt::WA_NativeWindow);
-
-
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	if (!edit)
 		connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
@@ -191,6 +190,8 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 		nameLineEdit->setText (this->target->name);
 
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
+
 		nameLabel = new QLabel(tr("Group Name"), this);
 		componentLayout->addWidget(nameLabel, 2, 1, 1, 2);
 
@@ -202,6 +203,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 		groupLineEdit->setText (this->target->groupName);
 
+		groupLineEdit->setFocusPolicy(Qt::StrongFocus);
 
 	}
 	else {
@@ -254,6 +256,9 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	    connect(typeLineEdit, SIGNAL(activated(int)), this, SLOT(emitCommitData(int)));
 
 		componentLayout->addWidget(typeLineEdit, 3, 3, 1, 4);
+
+		typeLineEdit->setFocusPolicy(Qt::StrongFocus);
+
 	}
 	else {
 		elType = -1;
@@ -408,6 +413,9 @@ void DetailWindow::_addField (TargetField * field) {
 
 	componentLayout->addWidget(nameLabel, pos, 0, 1, 1);
 	this->labels.append (nameLabel);
+
+	nameLabel->setFocusPolicy(Qt::StrongFocus);
+
 	//nameLabel->setContentsMargins(0, 10, 0, 0);
 	//ButtonInfo * info = new ButtonInfo (field);
 	//nameLabel->setUserData(0, info);
@@ -420,6 +428,7 @@ void DetailWindow::_addField (TargetField * field) {
 		this->values.append (nameLineEdit);
 		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 		componentLayout->setRowMinimumHeight(pos, 300);
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 		//nameLineEdit->setContentsMargins(0, 0, 20, 0);
 	}
 	else
@@ -429,6 +438,7 @@ void DetailWindow::_addField (TargetField * field) {
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
 		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 		//nameLineEdit->setContentsMargins(0, 0, 20, 0);
 	}
 	else
@@ -438,6 +448,7 @@ void DetailWindow::_addField (TargetField * field) {
 		nameLineEdit->setInputMethodHints(Qt::ImhDigitsOnly);
 		this->values.append (nameLineEdit);
 		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 		//nameLineEdit->setContentsMargins(0, 0, 20, 0);
 	}
 	else
@@ -447,17 +458,25 @@ void DetailWindow::_addField (TargetField * field) {
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
 		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 		//nameLineEdit->setContentsMargins(0, 0, 20, 0);
 	}
 	else
 	if (field->type == TYPE_PHONE_NUMBER) {
 		QLineEdit * nameLineEdit = new QLineEdit(this);
 		nameLineEdit->setText (field->value);
-		nameLineEdit->setInputMethodHints(Qt::ImhDigitsOnly);
+		if (settings.value("hints/phoneNumber/supportCharacters").toBool()) {
+			qDebug () << "phone support characters";
+			nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
+		}
+		else {
+			qDebug () << "phone only supports numbers";
+			nameLineEdit->setInputMethodHints(Qt::ImhDigitsOnly);
+		}
 		componentLayout->addWidget(nameLineEdit, pos, 1, 1, 1);
 		this->values.append (nameLineEdit);
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 		//nameLineEdit->setContentsMargins(0, 0, 20, 0);
-
 	}
 	else
 	if (field->type == TYPE_URL) {
@@ -467,6 +486,7 @@ void DetailWindow::_addField (TargetField * field) {
 		//nameLineEdit->setInputMethodHints(Qt::ImhUrlCharactersOnly);
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 		//nameLineEdit->setContentsMargins(0, 0, 20, 0);
 	}
 	else {
@@ -476,6 +496,7 @@ void DetailWindow::_addField (TargetField * field) {
 		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		nameLineEdit->setText (field->value);
 		this->values.append (nameLineEdit);
+		nameLineEdit->setFocusPolicy(Qt::StrongFocus);
 		//nameLineEdit->setContentsMargins(0, 0, 20, 0);
 
 		//nameLineEdit->setUserData(0,info);
@@ -757,6 +778,11 @@ void DetailWindow::saveTarget () {
 	close();
 }
 
+void DetailWindow::forceclose () {
+	forceClose = true;
+	close();
+}
+
 void DetailWindow::_deleteTarget () {
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 
@@ -1065,6 +1091,8 @@ void DetailWindow::takePicture () {
 #ifdef CAMERA
 	QCamera * cam = new QCamera;
 	connect (cam, SIGNAL(photoReady (QImage*)), this, SLOT(photoTake(QImage*)));
+
+	cam->takePhoto();
 #endif
 }
 
