@@ -138,6 +138,10 @@ signals:
 	void duplicateTarget(Target * source);
 public:
 	bool fieldsChanged;
+
+	void forceclose ();
+
+	QSettings settings;
 };
 
 class ButtonInfo: public QObjectUserData {
