@@ -136,7 +136,11 @@ eWallet::eWallet(QString * group, eWallet * _parent, QWidget *parent) : QMainWin
 
 eWallet::eWallet(QWidget *parent) : QMainWindow(parent)
 {
-	setWindowTitle("Wallet");
+    QCoreApplication::setOrganizationName("nowheremanmail");
+    QCoreApplication::setOrganizationDomain("gmail.com");
+    QCoreApplication::setApplicationName("qtWallet");
+
+    setWindowTitle("Wallet");
 
 	isFirst = true;
 	currentGroup = NULL;
@@ -352,7 +356,7 @@ void eWallet::listenInactivity(QString s) {
 	    }
 
 	    if (!detailWindowEdit.isNull()) {
-			detailWindowEdit->close();
+			detailWindowEdit->forceclose();
 			delete detailWindowEdit;
 			detailWindowEdit = 0;
 	    }
@@ -1634,7 +1638,7 @@ void eWallet::about() {
 			"<p>Developed by <b>nowheremanmail@gmail.com</b></p>"\
 			"<p>Icons by http://pixelmixer.ru/</p>"\
 			"<p>if you think that qtWallet is useful for you, please</p>"\
-			"<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>"));
+			"<a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted\">DONATE</a></qt>").arg(VERSION));
 }
 
 bool eWallet::finalPassword (const QString & pass) {
