@@ -77,32 +77,32 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="132"/>
         <source>Change Face Pict.</source>
-        <translation>Cambia Immagine</translation>
+        <translation>Cambia Immagine Anter.</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="133"/>
         <source>Mirror Face Pict.</source>
-        <translation>Immagine Routata</translation>
+        <translation>Ruota Immagine Anter.</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="134"/>
         <source>Change Back Pict.</source>
-        <translation>Cambia Imm Posteriore</translation>
+        <translation>Cambia Immagine Post.</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="135"/>
         <source>Mirror Back Pict.</source>
-        <translation>Imm. Posteriore Ruotata</translation>
+        <translation>Ruota Immagine Post.</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="136"/>
         <source>Delete Face Pict.</source>
-        <translation>Canc. Immagine</translation>
+        <translation>Cancella Immagine Ant.</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="137"/>
         <source>Delete Back Pict.</source>
-        <translation>Canc. Immagine Post.</translation>
+        <translation>Cancella Immagine Post.</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="138"/>
@@ -137,7 +137,7 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="151"/>
         <source>Export Back Pict.</source>
-        <translation>Eporta Imm. Posteriore</translation>
+        <translation>Esporta Immag Posteriore</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="178"/>
@@ -152,7 +152,7 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="207"/>
         <source>Membership Info</source>
-        <translation>Info sui Membri</translation>
+        <translation>Informazioni Membro/Socio</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="208"/>
@@ -177,7 +177,7 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="212"/>
         <source>Passport Info</source>
-        <translation>Info Passaporto</translation>
+        <translation>Passaporto</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="213"/>
@@ -187,22 +187,22 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="214"/>
         <source>Car Info</source>
-        <translation>Info Macchina</translation>
+        <translation>Informazioni Automobile</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="215"/>
         <source>Cellular Phone</source>
-        <translation>Numero Cellulare</translation>
+        <translation>Informazioni Cellulare</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="216"/>
         <source>Serial Number Software</source>
-        <translation>S/N Software</translation>
+        <translation>Informazioni Software</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="217"/>
         <source>Serial Number Hardware</source>
-        <translation>S/N Hardware</translation>
+        <translation>Informazioni Hardware</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="218"/>
@@ -212,12 +212,12 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="219"/>
         <source>ID Card</source>
-        <translation>ID della Carta</translation>
+        <translation>Numero ID della Carta</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="220"/>
         <source>Social Security Number</source>
-        <translation>Carta Sicurezza Sociale</translation>
+        <translation>Numero Social Security (U.S.A.)</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="221"/>
@@ -302,12 +302,12 @@
     <message>
         <location filename="../../DetailedWindow.cpp" line="977"/>
         <source>Choose card back image file</source>
-        <translation>Scegli l&apos;immagine posteriore</translation>
+        <translation>Scegli l'immagine posteriore</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="993"/>
         <source>Choose card back image</source>
-        <translation>Scegli l&apos;immagine posteriore</translation>
+        <translation>Scegli l'immagine posteriore</translation>
     </message>
     <message>
         <location filename="../../DetailedWindow.cpp" line="1052"/>
@@ -325,7 +325,7 @@
     <message>
         <location filename="../../LoginDialog.cpp" line="105"/>
         <source>Clear</source>
-        <translation>Pulisci</translation>
+        <translation>Cancella</translation>
     </message>
     <message>
         <location filename="../../LoginDialog.cpp" line="149"/>
@@ -340,7 +340,7 @@
     <message>
         <location filename="../../LoginDialog.cpp" line="165"/>
         <source>Exit</source>
-        <translation>Uscita</translation>
+        <translation>Esci</translation>
     </message>
     <message>
         <location filename="../../LoginDialog.cpp" line="221"/>
@@ -350,7 +350,7 @@
     <message>
         <location filename="../../LoginDialog.cpp" line="221"/>
         <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
-        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Desarrollado por &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Iconos por http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Si piensas que Wallet es util para ti, puedes &lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAR&lt;/a&gt;&lt;/qt&gt;</translation>
+        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.%1&lt;/p&gt;&lt;p&gt;Sviluppato da &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icone di http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Se pensi che qtWallet ti sia utile, per favore fai una&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAZIONE&lt;/a&gt;&lt;/qt&gt;</translation>
     </message>
     <message>
         <location filename="../../LoginDialog.cpp" line="243"/>
@@ -371,12 +371,12 @@
 <context>
     <name>RenameGroupDialog</name>
     <message>
-        <location filename="../../eWallet.cpp" line="51"/>
+        <location filename="../../eWallet.cpp" line="49"/>
         <source>Save &amp;&amp; Close</source>
         <translation>Salva e Esci</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="64"/>
+        <location filename="../../eWallet.cpp" line="62"/>
         <source>Name</source>
         <translation>Nome</translation>
     </message>
@@ -384,493 +384,493 @@
 <context>
     <name>eWallet</name>
     <message>
-        <location filename="../../eWallet.cpp" line="446"/>
+        <location filename="../../eWallet.cpp" line="444"/>
         <source>Are you sure you want to remove all your data? You will lost all your data</source>
         <translation>Sei sicuro di voler rimuovere tutti i dati? Perderai tutti i dati</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="471"/>
+        <location filename="../../eWallet.cpp" line="469"/>
         <source>Wrong password</source>
         <translation>Password Errata</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="368"/>
-        <location filename="../../eWallet.cpp" line="820"/>
+        <location filename="../../eWallet.cpp" line="366"/>
+        <location filename="../../eWallet.cpp" line="818"/>
         <source>&lt;All&gt;</source>
         <translation>&lt;Tutto&gt;</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="387"/>
-        <location filename="../../eWallet.cpp" line="829"/>
+        <location filename="../../eWallet.cpp" line="385"/>
+        <location filename="../../eWallet.cpp" line="827"/>
         <source>&lt;No Group&gt;</source>
         <translation>&lt;Nessun Gruppo&gt;</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="531"/>
+        <location filename="../../eWallet.cpp" line="529"/>
         <source>Organization</source>
         <translation>Organizzazione</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="532"/>
-        <location filename="../../eWallet.cpp" line="553"/>
-        <location filename="../../eWallet.cpp" line="603"/>
+        <location filename="../../eWallet.cpp" line="530"/>
+        <location filename="../../eWallet.cpp" line="551"/>
+        <location filename="../../eWallet.cpp" line="601"/>
         <source>Phone Number</source>
-        <translation>Numero di Telefono</translation>
+        <translation>Numero Telefono</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="533"/>
-        <location filename="../../eWallet.cpp" line="567"/>
+        <location filename="../../eWallet.cpp" line="531"/>
+        <location filename="../../eWallet.cpp" line="565"/>
         <source>Other Information</source>
         <translation>Altre Informazioni</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="534"/>
-        <location filename="../../eWallet.cpp" line="543"/>
-        <location filename="../../eWallet.cpp" line="645"/>
+        <location filename="../../eWallet.cpp" line="532"/>
+        <location filename="../../eWallet.cpp" line="541"/>
+        <location filename="../../eWallet.cpp" line="643"/>
         <source>User Name</source>
-        <translation>Soprannome</translation>
+        <translation>Nome Utente</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="535"/>
-        <location filename="../../eWallet.cpp" line="544"/>
-        <location filename="../../eWallet.cpp" line="571"/>
-        <location filename="../../eWallet.cpp" line="602"/>
-        <location filename="../../eWallet.cpp" line="631"/>
-        <location filename="../../eWallet.cpp" line="642"/>
-        <location filename="../../eWallet.cpp" line="646"/>
-        <location filename="../../eWallet.cpp" line="655"/>
+        <location filename="../../eWallet.cpp" line="533"/>
+        <location filename="../../eWallet.cpp" line="542"/>
+        <location filename="../../eWallet.cpp" line="569"/>
+        <location filename="../../eWallet.cpp" line="600"/>
+        <location filename="../../eWallet.cpp" line="629"/>
+        <location filename="../../eWallet.cpp" line="640"/>
+        <location filename="../../eWallet.cpp" line="644"/>
+        <location filename="../../eWallet.cpp" line="653"/>
         <source>Password</source>
         <translation>Password</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="536"/>
+        <location filename="../../eWallet.cpp" line="534"/>
         <source>Organization club</source>
         <translation>Club</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="537"/>
-        <location filename="../../eWallet.cpp" line="570"/>
-        <location filename="../../eWallet.cpp" line="636"/>
+        <location filename="../../eWallet.cpp" line="535"/>
+        <location filename="../../eWallet.cpp" line="568"/>
+        <location filename="../../eWallet.cpp" line="634"/>
         <source>ID Number</source>
-        <translation>Numero ID</translation>
+        <translation>Numero IDentific.</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="538"/>
-        <location filename="../../eWallet.cpp" line="545"/>
-        <location filename="../../eWallet.cpp" line="610"/>
-        <location filename="../../eWallet.cpp" line="629"/>
-        <location filename="../../eWallet.cpp" line="654"/>
+        <location filename="../../eWallet.cpp" line="536"/>
+        <location filename="../../eWallet.cpp" line="543"/>
+        <location filename="../../eWallet.cpp" line="608"/>
+        <location filename="../../eWallet.cpp" line="627"/>
+        <location filename="../../eWallet.cpp" line="652"/>
         <source>URL</source>
         <translation>URL</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="539"/>
-        <location filename="../../eWallet.cpp" line="559"/>
-        <location filename="../../eWallet.cpp" line="573"/>
-        <location filename="../../eWallet.cpp" line="648"/>
-        <location filename="../../eWallet.cpp" line="658"/>
+        <location filename="../../eWallet.cpp" line="537"/>
+        <location filename="../../eWallet.cpp" line="557"/>
+        <location filename="../../eWallet.cpp" line="571"/>
+        <location filename="../../eWallet.cpp" line="646"/>
+        <location filename="../../eWallet.cpp" line="656"/>
         <source>Card Notes</source>
         <translation>Note Carta</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="542"/>
-        <location filename="../../eWallet.cpp" line="647"/>
+        <location filename="../../eWallet.cpp" line="540"/>
+        <location filename="../../eWallet.cpp" line="645"/>
         <source>System</source>
         <translation>Sistema</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="548"/>
+        <location filename="../../eWallet.cpp" line="546"/>
         <source>Credit Card Type</source>
-        <translation>Tipo Carta di Credito</translation>
+        <translation>Tipo Carta</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="549"/>
+        <location filename="../../eWallet.cpp" line="547"/>
         <source>Card Provider</source>
-        <translation>Gestore Carta</translation>
+        <translation>Fornita da</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="550"/>
+        <location filename="../../eWallet.cpp" line="548"/>
         <source>Card Number</source>
         <translation>Numero Carta</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="551"/>
-        <location filename="../../eWallet.cpp" line="556"/>
-        <location filename="../../eWallet.cpp" line="653"/>
+        <location filename="../../eWallet.cpp" line="549"/>
+        <location filename="../../eWallet.cpp" line="554"/>
+        <location filename="../../eWallet.cpp" line="651"/>
         <source>Expiration Date</source>
         <translation>Data Scadenza</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="552"/>
+        <location filename="../../eWallet.cpp" line="550"/>
         <source>Name on Card</source>
         <translation>Nome sulla Carta</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="554"/>
-        <location filename="../../eWallet.cpp" line="565"/>
+        <location filename="../../eWallet.cpp" line="552"/>
+        <location filename="../../eWallet.cpp" line="563"/>
         <source>PIN</source>
         <translation>PIN</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="555"/>
+        <location filename="../../eWallet.cpp" line="553"/>
         <source>Start Date</source>
         <translation>Data Inizio</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="557"/>
+        <location filename="../../eWallet.cpp" line="555"/>
         <source>Detail</source>
         <translation>Dettagli</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="558"/>
+        <location filename="../../eWallet.cpp" line="556"/>
         <source>3-digit CVC#</source>
-        <translation>CVC (3 numeri)</translation>
+        <translation>CVC</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="562"/>
+        <location filename="../../eWallet.cpp" line="560"/>
         <source>Bank Name</source>
         <translation>Nome Banca</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="563"/>
+        <location filename="../../eWallet.cpp" line="561"/>
         <source>Account Number</source>
         <translation>Numero Conto</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="564"/>
+        <location filename="../../eWallet.cpp" line="562"/>
         <source>Telephone</source>
         <translation>Telefono</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="566"/>
+        <location filename="../../eWallet.cpp" line="564"/>
         <source>SWIFT Code</source>
         <translation>Codice SWIFT</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="572"/>
-        <location filename="../../eWallet.cpp" line="637"/>
+        <location filename="../../eWallet.cpp" line="570"/>
+        <location filename="../../eWallet.cpp" line="635"/>
         <source>Card Title</source>
-        <translation>Titolo Carta</translation>
+        <translation>Num ID Istituzione</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="574"/>
+        <source>Passport No</source>
+        <translation>Numero Passapor.</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="575"/>
+        <source>Surname</source>
+        <translation>Cognome</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="576"/>
-        <source>Passport No</source>
-        <translation>Numero Passaporto</translation>
+        <source>Given names</source>
+        <translation>Nome</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="577"/>
-        <source>Surname</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../eWallet.cpp" line="578"/>
-        <source>Given names</source>
-        <translation>Secondo Nome</translation>
-    </message>
-    <message>
-        <location filename="../../eWallet.cpp" line="579"/>
         <source>Date of birth</source>
         <translation>Data di Nascita</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="580"/>
+        <location filename="../../eWallet.cpp" line="578"/>
         <source>Date of issue</source>
         <translation>Data di emissione</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="581"/>
+        <location filename="../../eWallet.cpp" line="579"/>
         <source>Date of expiration</source>
         <translation>Data di Scadenza</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="582"/>
+        <location filename="../../eWallet.cpp" line="580"/>
         <source>Authority</source>
         <translation>Autorità</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="585"/>
+        <location filename="../../eWallet.cpp" line="583"/>
         <source>Text</source>
         <translation>Testo</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="588"/>
-        <location filename="../../eWallet.cpp" line="592"/>
+        <location filename="../../eWallet.cpp" line="586"/>
+        <location filename="../../eWallet.cpp" line="590"/>
         <source>Model</source>
         <translation>Modello</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="589"/>
+        <location filename="../../eWallet.cpp" line="587"/>
         <source>Vehicle Number</source>
         <translation>Numero Veicolo</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="593"/>
+        <location filename="../../eWallet.cpp" line="591"/>
         <source>Brand</source>
         <translation>Marca</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="594"/>
+        <location filename="../../eWallet.cpp" line="592"/>
         <source>IMEI#</source>
         <translation>IMEI</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="595"/>
+        <location filename="../../eWallet.cpp" line="593"/>
         <source>Firmware code</source>
         <translation>Codice Firmware</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="596"/>
+        <location filename="../../eWallet.cpp" line="594"/>
         <source>Purchased</source>
         <translation>Aquistato il</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="597"/>
+        <location filename="../../eWallet.cpp" line="595"/>
         <source>Pin1</source>
-        <translation>Pi1</translation>
+        <translation>PIN 1</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="596"/>
+        <source>Pin2</source>
+        <translation>PIN 2</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="597"/>
+        <source>Puk1</source>
+        <translation>PUK 1</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="598"/>
-        <source>Pin2</source>
-        <translation>Pin2</translation>
+        <source>Puk2</source>
+        <translation>PUK 2</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="599"/>
-        <source>Puk1</source>
-        <translation>Puk1</translation>
-    </message>
-    <message>
-        <location filename="../../eWallet.cpp" line="600"/>
-        <source>Puk2</source>
-        <translation>Puk2</translation>
-    </message>
-    <message>
-        <location filename="../../eWallet.cpp" line="601"/>
         <source>Num SIM</source>
         <translation>Numero SIM</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="604"/>
+        <location filename="../../eWallet.cpp" line="602"/>
         <source>Manufacturer</source>
         <translation>Produttore</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="607"/>
-        <location filename="../../eWallet.cpp" line="621"/>
+        <location filename="../../eWallet.cpp" line="605"/>
+        <location filename="../../eWallet.cpp" line="619"/>
         <source>Product</source>
         <translation>Prodotto</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="608"/>
+        <location filename="../../eWallet.cpp" line="606"/>
         <source>Version</source>
         <translation>Versione</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="609"/>
-        <location filename="../../eWallet.cpp" line="622"/>
+        <location filename="../../eWallet.cpp" line="607"/>
+        <location filename="../../eWallet.cpp" line="620"/>
         <source>Serial #</source>
         <translation>Seriale</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="611"/>
+        <location filename="../../eWallet.cpp" line="609"/>
         <source>Company</source>
         <translation>Compagnia</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="612"/>
+        <location filename="../../eWallet.cpp" line="610"/>
         <source>Date bought</source>
         <translation>Data di Acquisto</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="613"/>
+        <location filename="../../eWallet.cpp" line="611"/>
         <source>Username</source>
-        <translation>Username</translation>
+        <translation>Nome Utente</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="614"/>
-        <location filename="../../eWallet.cpp" line="630"/>
+        <location filename="../../eWallet.cpp" line="612"/>
+        <location filename="../../eWallet.cpp" line="628"/>
         <source>Login</source>
         <translation>Login</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="615"/>
+        <location filename="../../eWallet.cpp" line="613"/>
         <source>Authorization key</source>
-        <translation>Chiave di Autorizzazione</translation>
+        <translation>Chiave Autoriz.</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="616"/>
-        <location filename="../../eWallet.cpp" line="625"/>
+        <location filename="../../eWallet.cpp" line="614"/>
+        <location filename="../../eWallet.cpp" line="623"/>
         <source>Price paid</source>
         <translation>Prezzo Pagato</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="617"/>
+        <location filename="../../eWallet.cpp" line="615"/>
         <source>Support</source>
         <translation>Supporto</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="618"/>
-        <location filename="../../eWallet.cpp" line="633"/>
+        <location filename="../../eWallet.cpp" line="616"/>
+        <location filename="../../eWallet.cpp" line="631"/>
         <source>Notes</source>
         <translation>Note</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="623"/>
+        <location filename="../../eWallet.cpp" line="621"/>
         <source>Model #</source>
-        <translation>Modello</translation>
+        <translation>Modello #</translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="622"/>
+        <source>Bought from</source>
+        <translation>Acquistato da</translation>
     </message>
     <message>
         <location filename="../../eWallet.cpp" line="624"/>
-        <source>Bought from</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../../eWallet.cpp" line="626"/>
         <source>Guarantee period</source>
         <translation>Periodo Garanzia</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="632"/>
+        <location filename="../../eWallet.cpp" line="630"/>
         <source>E mail used</source>
         <translation>E-mail utilizzata</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="640"/>
+        <location filename="../../eWallet.cpp" line="638"/>
         <source>Social Security Number</source>
-        <translation>Numero di Sicurezza Sociale</translation>
+        <translation>Numero</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="641"/>
+        <location filename="../../eWallet.cpp" line="639"/>
         <source>Name</source>
         <translation>Nome</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="651"/>
+        <location filename="../../eWallet.cpp" line="649"/>
         <source>Driver&apos;s License Number</source>
         <translation>Numero Patente</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="652"/>
+        <location filename="../../eWallet.cpp" line="650"/>
         <source>Date Issued</source>
         <translation>Data Rilascio</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="909"/>
+        <location filename="../../eWallet.cpp" line="907"/>
         <source>About</source>
-        <translation>Info</translation>
+        <translation>Info su</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="911"/>
+        <location filename="../../eWallet.cpp" line="909"/>
         <source>Delete DB</source>
         <translation>Cancella DB</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="913"/>
-        <location filename="../../eWallet.cpp" line="924"/>
+        <location filename="../../eWallet.cpp" line="911"/>
+        <location filename="../../eWallet.cpp" line="922"/>
         <source>Exit</source>
         <translation>Esci</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="916"/>
+        <location filename="../../eWallet.cpp" line="914"/>
         <source>New</source>
         <translation>Nuovo</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="918"/>
-        <location filename="../../eWallet.cpp" line="1392"/>
+        <location filename="../../eWallet.cpp" line="916"/>
+        <location filename="../../eWallet.cpp" line="1390"/>
         <source>Edit</source>
         <translation>Modifica</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="919"/>
+        <location filename="../../eWallet.cpp" line="917"/>
         <source>Invert Sort</source>
         <translation>Inverti Ordinamento</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="920"/>
+        <location filename="../../eWallet.cpp" line="918"/>
         <source>Import</source>
         <translation>Importa</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="921"/>
+        <location filename="../../eWallet.cpp" line="919"/>
         <source>Export</source>
         <translation>Esporta</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="923"/>
+        <location filename="../../eWallet.cpp" line="921"/>
         <source>Change Password</source>
         <translation>Cambia Password</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="983"/>
+        <location filename="../../eWallet.cpp" line="981"/>
         <source>Are you sure you want to remove it?</source>
         <translation>Sei sicuro di rimuoverlo?</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1131"/>
+        <location filename="../../eWallet.cpp" line="1129"/>
         <source>Choose import file</source>
         <translation>Scegli il file da importare</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1133"/>
-        <location filename="../../eWallet.cpp" line="1411"/>
+        <location filename="../../eWallet.cpp" line="1131"/>
+        <location filename="../../eWallet.cpp" line="1409"/>
         <source>Text files (*.txt);;</source>
         <translation>File Testo (*.txt)</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1381"/>
+        <location filename="../../eWallet.cpp" line="1379"/>
         <source>Rename</source>
         <translation>Rinomina</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1382"/>
-        <location filename="../../eWallet.cpp" line="1395"/>
+        <location filename="../../eWallet.cpp" line="1380"/>
+        <location filename="../../eWallet.cpp" line="1393"/>
         <source>Delete</source>
         <translation>Cancella</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1391"/>
+        <location filename="../../eWallet.cpp" line="1389"/>
         <source>View</source>
         <translation>Visualizza</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1393"/>
+        <location filename="../../eWallet.cpp" line="1391"/>
         <source>New like this</source>
         <translation>Nuovo come questo</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1394"/>
+        <location filename="../../eWallet.cpp" line="1392"/>
         <source>Duplicate</source>
         <translation>Duplica</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1409"/>
+        <location filename="../../eWallet.cpp" line="1407"/>
         <source>Choose export file</source>
         <translation>Scegli il file di esportazione</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1617"/>
+        <location filename="../../eWallet.cpp" line="1615"/>
         <source>About Wallet</source>
         <translation>Info su Wallet</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1617"/>
+        <location filename="../../eWallet.cpp" line="1615"/>
         <source>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;qtWallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Developed by &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icons by http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;if you think that qtWallet is useful for you, please&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONATE&lt;/a&gt;&lt;/qt&gt;</source>
-        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.1.0&lt;/p&gt;&lt;p&gt;Desarrollado por &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Iconos por http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Si piensas que Wallet es util para ti, puedes &lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAR&lt;/a&gt;&lt;/qt&gt;</translation>
+        <translation>&lt;qt&gt;&lt;br&gt;&lt;br&gt;&lt;p&gt;&lt;i&gt;&lt;b&gt;Wallet&lt;/b&gt;&lt;/i&gt;, v.%1&lt;/p&gt;&lt;p&gt;Sviluppato da &lt;b&gt;nowheremanmail@gmail.com&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Icone di http://pixelmixer.ru/&lt;/p&gt;&lt;p&gt;Se pensi che qtWallet ti sia utile, gentilmente fai una&lt;/p&gt;&lt;a href=&quot;https://www.paypal.com/cgi-bin/webscr?cmd=_donations&amp;business=nowheremanmail@gmail.com&amp;lc=US&amp;item_name=qtWallet&amp;currency_code=EUR&amp;bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted&quot;&gt;DONAZIONE&lt;/a&gt;&lt;/qt&gt;</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1656"/>
+        <location filename="../../eWallet.cpp" line="1654"/>
         <source>Changing password, please wait until application quits</source>
         <translation>Cambio Password, per favore aspetta la chiusura della applicazione</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1662"/>
+        <location filename="../../eWallet.cpp" line="1660"/>
         <source>Password changed successfully, application will exit</source>
-        <translation>Password Cambiata con successo, chiusura dell&apos;applicazione</translation>
+        <translation>Password Cambiata con successo, l'applicazione verrà chiusa</translation>
     </message>
     <message>
-        <location filename="../../eWallet.cpp" line="1664"/>
+        <location filename="../../eWallet.cpp" line="1662"/>
         <source>Password CANNOT BE changed, because %1, and application will exit</source>
-        <translation>La Password non è stata cambiata, perchè %1, chiusura dell&apos;applicazione</translation>
+        <translation>La Password non è stata cambiata, perchè %1, l'applicazione verrà chiusa</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
